
# json-api-nestjs

## Installation

```bash  
$ npm install json-api-nestjs
```  

## Example

Once the installation process is complete, we can import the **JsonApiModule** into the root **AppModule**.

```typescript
import { Module } from '@nestjs/common';
import { JsonApiModule } from 'json-api-nestjs';
import { Users } from 'database';

@Module({
  imports: [
    JsonApiModule.forRoot({  
	  entities: [Users]
	}),
  ],
})
export class AppModule {}
```
After this, you have prepare crude with ready to use end point:


- GET /users
- POST /users
- GET /users/:id
- PATCH /users/:id
- DELETE /users/:id
- GET /users/{id}/relationships/{relName}
- POST /users/{id}/relationships/{relName}
- PATCH /users/{id}/relationships/{relName}
- DELETE /users/{id}/relationships/{relName}

## Configuration params

The following interface is using for the configuration:
```typescript
export interface ModuleOptions {  
    entities: Entity[]; // List of typeOrm Entity
    controllers?: NestController[];  // List of controller, if you need extend default present
    connectionName?: string; // Type orm connection name: "default" is default name  
    providers?: NestProvider[]; // List of addition provider for useing in custom controller
    options?: {  
	  requiredSelectField?: boolean; // Need list of select field in get endpoint, try is default
	  debug?: boolean; // Debug info in result object
	};  
}
```
You can extend default controller:
```typescript
import { Get, Param, Inject, BadRequestException } from '@nestjs/common';  
  
import { Users } from 'database';  
import {  
  JsonApi,  
  excludeMethod,  
  JsonBaseController,  
  InjectService,  
  JsonApiService,  
  QueryParams,  
} from 'json-api-nestjs';  
import { ExampleService } from '../../service/example/example.service';  
  
@JsonApi(Users, {  
  allowMethod: excludeMethod(['deleteRelationship']),  
  requiredSelectField: true,  
})  
export class ExtendUserController extends JsonBaseController<Users> {  
  @InjectService() public service: JsonApiService<Users>;  
  @Inject(ExampleService) protected exampleService: ExampleService;  
  
  public override getAll(query: QueryParams<Users>) { 
	if (!this.exampleService.someCheck(query)) {
		throw new BadRequestException({});
	}
    return this.service.getAll({ query });  
  }  
  
  @Get(':id/example')  
  testOne(@Param('id') id: string): string {  
    return this.exampleService.testMethode(id);  
  }  
}
```

## Swagger UI

For using swagger, you should only add [@nestjs/swagger](https://docs.nestjs.com/openapi/introduction)


##  Filter operand

```typescript
type FilterOperand = {
	in: string[], // is equal to the conditional of query "WHERE 'attribute_name' IN ('value1', 'value2')"
	nin: string[], // is equal to the conditional of query "WHERE 'attribute_name' NOT IN ('value1', 'value1')"
	eq: string, // is equal to the conditional of query "WHERE 'attribute_name' = 'value1'
	ne: string, // is equal to the conditional of query "WHERE 'attribute_name' <> 'value1'
	gte: string, // is equal to the conditional of query "WHERE 'attribute_name' >= 'value1'
	gt: string, // is equal to the conditional of query "WHERE 'attribute_name' > 'value1'
	lt: string, // is equal to the conditional of query "WHERE 'attribute_name' < 'value1'
	lte:string, // is equal to the conditional of query "WHERE 'attribute_name' <= 'value1'
	regexp: string, // is equal to the conditional of query "WHERE 'attribute_name' ~* value1
	some: string, // is equal to the conditional of query "WHERE 'attribute_name' && [value1]
}
```
