"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getRelationship = void 0;
const swagger_1 = require("@nestjs/swagger");
const utils_1 = require("../utils");
const index_1 = require("./index");
function getRelationship(controller, entity, binding, config) {
    const entityName = entity instanceof Function ? entity.name : entity.options.name;
    const descriptor = Reflect.getOwnPropertyDescriptor(controller.prototype, binding.name);
    const relationsOptions = (0, utils_1.getRelationsOptions)(entity);
    if (!descriptor) {
        return;
    }
    (0, swagger_1.ApiParam)({
        name: 'id',
        required: true,
        type: 'integer',
        description: `ID of resource "${entityName}"`,
    })(controller.prototype, binding.name, descriptor);
    (0, swagger_1.ApiParam)({
        name: 'relName',
        required: true,
        type: 'string',
        enum: Object.keys(relationsOptions),
        description: `Relation name of resource "${entityName}"`,
    })(controller.prototype, binding.name, descriptor);
    const dataType = {
        type: 'object',
        properties: {
            type: {
                type: 'string',
            },
            id: {
                type: 'string',
            },
        },
    };
    (0, swagger_1.ApiResponse)({
        status: 200,
        schema: {
            type: 'object',
            properties: {
                data: {
                    oneOf: [
                        dataType,
                        {
                            type: 'array',
                            items: dataType,
                            minItems: 1,
                        },
                    ],
                },
            },
        },
        description: `Item/s of relation of "${entityName}". Relationships received successfully. Response 'data' field depends on relationship type.
For many-to-many relations it should contain an array.`,
    })(controller.prototype, binding.name, descriptor);
    (0, swagger_1.ApiResponse)({
        status: 400,
        description: 'Wrong url parameters',
        schema: index_1.errorSchema,
    })(controller.prototype, binding.name, descriptor);
    (0, swagger_1.ApiOperation)({
        summary: `Get list of relation for resource "${entityName}"`,
        operationId: `${controller.name}_${binding.name}`,
    })(controller.prototype, binding.name, descriptor);
}
exports.getRelationship = getRelationship;
//# sourceMappingURL=get-relationship.js.map